@@ -29,8 +29,9 @@ class ConnectionRow extends Gtk.ListBoxRow {
         let name = NetworksManager.getDefault().getNetworkName(this._id);
         this.name = `ConnectionRow ${name}`;
 
-        this.bind_property('sensitive', this, 'activatable',
-                           GObject.BindingFlags.SYNC_CREATE);
+        this.bind_property('sensitive',
+            this, 'activatable',
+            GObject.BindingFlags.SYNC_CREATE);
 
         let box = new Gtk.Box({ spacing: 12, margin: 12 });
         this.add(box);
@@ -47,9 +48,10 @@ class ConnectionRow extends Gtk.ListBoxRow {
 
         this.show_all();
 
-        this.bind_property('sensitive', insensitiveDesc, 'visible',
-                           GObject.BindingFlags.SYNC_CREATE |
-                           GObject.BindingFlags.INVERT_BOOLEAN);
+        this.bind_property('sensitive',
+            insensitiveDesc, 'visible',
+            GObject.BindingFlags.SYNC_CREATE |
+            GObject.BindingFlags.INVERT_BOOLEAN);
     }
 
     get id() {
@@ -59,12 +61,10 @@ class ConnectionRow extends Gtk.ListBoxRow {
 
 var ConnectionsList = GObject.registerClass({
     Properties: {
-        'favorites-only': GObject.ParamSpec.boolean('favorites-only',
-                                                    'favorites-only',
-                                                    'favorites-only',
-                                                    GObject.ParamFlags.READWRITE |
-                                                    GObject.ParamFlags.CONSTRUCT_ONLY,
-                                                    false)
+        'favorites-only': GObject.ParamSpec.boolean(
+            'favorites-only', 'favorites-only', 'favorites-only',
+            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT_ONLY,
+            false)
     },
     Signals: {
         'account-created': { param_types: [Tp.Account.$gtype] },
@@ -120,9 +120,8 @@ var ConnectionsList = GObject.registerClass({
             });
 
         this._networksManager = NetworksManager.getDefault();
-        let networksChangedId =
-            this._networksManager.connect('changed',
-                                          this._networksChanged.bind(this));
+        let networksChangedId = this._networksManager.connect('changed',
+            this._networksChanged.bind(this));
         this._networksChanged();
 
         this.connect('destroy', () => {
@@ -255,16 +254,14 @@ var ConnectionDetails = GObject.registerClass({
         'sslCheckbox'
     ],
     Properties: {
-        'can-confirm': GObject.ParamSpec.boolean('can-confirm',
-                                                 'can-confirm',
-                                                 'can-confirm',
-                                                 GObject.ParamFlags.READABLE,
-                                                 false),
-        'has-serivce': GObject.ParamSpec.boolean('has-service',
-                                                 'has-service',
-                                                 'has-service',
-                                                 GObject.ParamFlags.READABLE,
-                                                 false)
+        'can-confirm': GObject.ParamSpec.boolean(
+            'can-confirm', 'can-confirm', 'can-confirm',
+            GObject.ParamFlags.READABLE,
+            false),
+        'has-serivce': GObject.ParamSpec.boolean(
+            'has-service', 'has-service', 'has-service',
+            GObject.ParamFlags.READABLE,
+            false)
     },
     Signals: {
         'account-created': { param_types: [Tp.Account.$gtype] }
@@ -285,15 +282,15 @@ var ConnectionDetails = GObject.registerClass({
         });
 
         this._nameEntry.connect('changed',
-                                this._onCanConfirmChanged.bind(this));
+            this._onCanConfirmChanged.bind(this));
         this._serverEntry.connect('changed',
-                                  this._onCanConfirmChanged.bind(this));
+            this._onCanConfirmChanged.bind(this));
         this._nickEntry.connect('changed',
-                                this._onCanConfirmChanged.bind(this));
+            this._onCanConfirmChanged.bind(this));
         this._realnameEntry.connect('changed',
-                                    this._onCanConfirmChanged.bind(this));
+            this._onCanConfirmChanged.bind(this));
         this._sslCheckbox.connect('toggled',
-                                  this._onCanConfirmChanged.bind(this));
+            this._onCanConfirmChanged.bind(this));
 
         let realnameStore = new Gtk.ListStore();
         realnameStore.set_column_types([GObject.TYPE_STRING]);
@@ -524,7 +521,7 @@ var ConnectionProperties = GObject.registerClass({
         this.set_default_response(Gtk.ResponseType.OK);
 
         let id = account.connect('notify::connection-status',
-                                 this._syncErrorMessage.bind(this));
+            this._syncErrorMessage.bind(this));
         this._syncErrorMessage(account);
 
         this.connect('destroy', () => account.disconnect(id));
