@@ -4,9 +4,7 @@ const {
     Gio, GLib, GObject, Gtk, Pango, Polari, TelepathyGLib: Tp
 } = imports.gi;
 
-const READWRITE = GObject.ParamFlags.READABLE | GObject.ParamFlags.WRITABLE;
-
-const MAX_USERS_SHOWN = 8;
+const FILTER_ENTRY_THRESHOLD = 8;
 const MAX_USERS_WIDTH_CHARS = 17;
 
 var UserListPopover = GObject.registerClass(
@@ -19,6 +17,7 @@ class UserListPopover extends Gtk.Popover {
         this.connect('closed', () => this._entry.text = '');
         this.connect('map', () => {
             this._revealer.transition_duration = 0;
+            this._updateContentHeight();
             this._ensureUserList();
         });
         this._revealer.connect('notify::child-revealed', () => {
@@ -31,7 +30,9 @@ class UserListPopover extends Gtk.Popover {
 
         let toplevel = this.get_toplevel();
         toplevel.connect('notify::active-room',
-                         this._activeRoomChanged.bind(this));
+            this._activeRoomChanged.bind(this));
+        toplevel.connect('notify::view-height',
+            this._updateContentHeight.bind(this));
     }
 
     _createWidget() {
@@ -44,7 +45,9 @@ class UserListPopover extends Gtk.Popover {
         this._revealer = new Gtk.Revealer();
         this._box.add(this._revealer);
 
-        this._userListBin = new Gtk.Frame({ shadow_type: Gtk.ShadowType.NONE });
+        this._userListBin = new Gtk.Frame({
+            shadow_type: Gtk.ShadowType.NONE
+        });
         this._box.add(this._userListBin);
 
         this._entry = new Gtk.SearchEntry({
@@ -64,6 +67,19 @@ class UserListPopover extends Gtk.Popover {
         this._userList = null;
     }
 
+    _updateContentHeight() {
+        if (!this._userList)
+            return;
+        if (!this.get_mapped())
+            return;
+
+        let viewHeight = this.get_toplevel().view_height;
+        let [popoverHeight] = this.get_preferred_height();
+        let [userListHeight] = this._userList.get_preferred_height();
+        let chromeHeight = popoverHeight - userListHeight;
+        this._userList.max_content_height = viewHeight - chromeHeight;
+    }
+
     _ensureUserList() {
         if (this._userList)
             return;
@@ -76,8 +92,9 @@ class UserListPopover extends Gtk.Popover {
         this._userListBin.add(this._userList);
 
         this._userList.vadjustment.connect('changed',
-                                           this._updateEntryVisibility.bind(this));
+            this._updateEntryVisibility.bind(this));
         this._updateEntryVisibility();
+        this._updateContentHeight();
     }
 
     _updateEntryVisibility() {
@@ -85,7 +102,7 @@ class UserListPopover extends Gtk.Popover {
             return;
 
         let reveal = this._entry.text != '' ||
-                     this._userList.numRows > MAX_USERS_SHOWN;
+                     this._userList.numRows > FILTER_ENTRY_THRESHOLD;
         this._revealer.reveal_child = reveal;
     }
 
@@ -108,16 +125,14 @@ var UserDetails = GObject.registerClass({
         'messageButton'
     ],
     Properties: {
-        'expanded': GObject.ParamSpec.boolean('expanded',
-                                              'expanded',
-                                              'expanded',
-                                              READWRITE,
-                                              false),
-        'notifications-enabled': GObject.ParamSpec.boolean('notifications-enabled',
-                                                           'notifications-enabled',
-                                                           'notifications-enabled',
-                                                           READWRITE,
-                                                           false)
+        'expanded': GObject.ParamSpec.boolean(
+            'expanded', 'expanded', 'expanded',
+            GObject.ParamFlags.READWRITE,
+            false),
+        'notifications-enabled': GObject.ParamSpec.boolean(
+            'notifications-enabled', 'notifications-enabled', 'notifications-enabled',
+            GObject.ParamFlags.READWRITE,
+            false)
     }
 }, class UserDetails extends Gtk.Frame {
     _init(params = {}) {
@@ -134,7 +149,7 @@ var UserDetails = GObject.registerClass({
         this.user = user;
 
         this._messageButton.connect('clicked',
-                                    this._onMessageButtonClicked.bind(this));
+            this._onMessageButtonClicked.bind(this));
 
         this._updateButtonVisibility();
         this._detailsGrid.hide();
@@ -171,7 +186,7 @@ var UserDetails = GObject.registerClass({
         if (this._user) {
             this._selfContactChangedId =
                 this._user.connection.connect('notify::self-contact',
-                                              this._updateButtonVisibility.bind(this));
+                    this._updateButtonVisibility.bind(this));
         }
 
         if (this.expanded)
@@ -218,8 +233,9 @@ var UserDetails = GObject.registerClass({
         this._cancellable = new Gio.Cancellable();
 
         if (this._user) {
-            this._user.request_contact_info_async(this._cancellable,
-                                                  this._onContactInfoReady.bind(this));
+            this._user.request_contact_info_async(
+                this._cancellable,
+                this._onContactInfoReady.bind(this));
         } else {
             //TODO: else use this._nickname to query tracker
             this._revealDetails();
@@ -236,37 +252,43 @@ var UserDetails = GObject.registerClass({
 
     _formatLast(seconds) {
         if (seconds < 60) {
-            return ngettext('%d second ago',
-                            '%d seconds ago', seconds).format(seconds);
+            return ngettext(
+                '%d second ago',
+                '%d seconds ago', seconds).format(seconds);
         }
 
         let minutes = seconds / 60;
         if (minutes < 60) {
-            return ngettext('%d minute ago',
-                            '%d minutes ago', minutes).format(minutes);
+            return ngettext(
+                '%d minute ago',
+                '%d minutes ago', minutes).format(minutes);
         }
 
         let hours = minutes / 60;
         if (hours < 24) {
-            return ngettext('%d hour ago',
-                            '%d hours ago', hours).format(hours);
+            return ngettext(
+                '%d hour ago',
+                '%d hours ago', hours).format(hours);
         }
 
         let days = hours / 24;
         if (days < 7) {
-            return ngettext('%d day ago',
-                            '%d days ago', days).format(days);
+            return ngettext(
+                '%d day ago',
+                '%d days ago', days).format(days);
         }
 
         let weeks = days / 7;
         if (days < 30) {
-            return ngettext('%d week ago',
-                            '%d weeks ago', weeks).format(weeks);
+            return ngettext(
+                '%d week ago',
+                '%d weeks ago', weeks).format(weeks);
         }
 
         let months = days / 30;
-        return ngettext('%d month ago',
-                        '%d months ago', months).format(months);
+        return ngettext(
+            '%d month ago',
+            '%d months ago', months).format(months);
     }
 
     _onContactInfoReady() {
@@ -392,17 +414,18 @@ var UserPopover = GObject.registerClass({
 
         this._basenick = basenick;
 
-        if (this._roomStatusChangedId > 0)
-            this._userTracker.unwatchRoomStatus(this._room, this._roomStatusChangedId);
-        this._roomStatusChangedId =
-            this._userTracker.watchRoomStatus(this._room, this._basenick,
-                                              this._onStatusChanged.bind(this));
+        if (this._roomStatusChangedId > 0) {
+            this._userTracker.unwatchRoomStatus(
+                this._room, this._roomStatusChangedId);
+        }
+        this._roomStatusChangedId = this._userTracker.watchRoomStatus(
+            this._room, this._basenick, this._onStatusChanged.bind(this));
 
         if (this._globalStatusChangedId > 0)
             this._userTracker.disconnect(this._globalStatusChangedId);
         this._globalStatusChangedId =
             this._userTracker.connect(`status-changed::${basenick}`,
-                                      this._onStatusChanged.bind(this));
+                this._onStatusChanged.bind(this));
 
         if (this._contactsChangedId > 0)
             this._userTracker.disconnect(this._contactsChangedId);
@@ -421,8 +444,8 @@ var UserPopover = GObject.registerClass({
 
     _onStatusChanged() {
         let status = this._userTracker.getNickStatus(this._nickname);
-        let roomStatus = this._userTracker.getNickRoomStatus(this._nickname,
-                                                             this._room);
+        let roomStatus = this._userTracker.getNickRoomStatus(
+            this._nickname, this._room);
 
         let label;
         if (status != roomStatus)
@@ -454,10 +477,10 @@ class UserListRow extends Gtk.ListBoxRow {
             this._revealer.reveal_child = false;
         });
         this.connect('state-flags-changed',
-                     this._updateArrowVisibility.bind(this));
+            this._updateArrowVisibility.bind(this));
 
         this._revealer.connect('notify::reveal-child',
-                               this._onExpandedChanged.bind(this));
+            this._onExpandedChanged.bind(this));
     }
 
     get user() {
@@ -536,8 +559,11 @@ class UserListRow extends Gtk.ListBoxRow {
             this._label.label = this._user.alias;
         } else {
             let preMatch = this._user.alias.substring(0, filterIndex);
-            let theMatch = this._user.alias.substring(filterIndex, filterIndex + this._filter.length);
-            let postMatch = this._user.alias.substring(filterIndex + this._filter.length);
+            let theMatch = this._user.alias.substring(
+                filterIndex,
+                filterIndex + this._filter.length);
+            let postMatch = this._user.alias.substring(
+                filterIndex + this._filter.length);
             this._label.label = `${preMatch}<b>${theMatch}<${'/'}b>${postMatch}`;
         }
     }
@@ -568,16 +594,18 @@ class UserList extends Gtk.ScrolledWindow {
             hexpand: true,
             shadow_type: Gtk.ShadowType.ETCHED_IN,
             hscrollbar_policy: Gtk.PolicyType.NEVER,
+            propagate_natural_height: true,
             propagate_natural_width: true
         });
 
         this._list = new Gtk.ListBox({ vexpand: true });
         this.add(this._list);
-
         let placeholder = new Gtk.Box({
             halign: Gtk.Align.CENTER,
             valign: Gtk.Align.CENTER,
             orientation: Gtk.Orientation.VERTICAL,
+            margin: 32,
+            spacing: 6,
             visible: true
         });
         placeholder.add(new Gtk.Image({
@@ -586,18 +614,14 @@ class UserList extends Gtk.ScrolledWindow {
             visible: true
         }));
         placeholder.add(new Gtk.Label({
-            label: _('No results'),
+            label: _('No Results'),
             visible: true
         }));
 
-        placeholder.get_style_context().add_class('dim-label');
+        placeholder.get_style_context().add_class('placeholder');
 
         this._list.set_placeholder(placeholder);
 
-        this._updateHeightId = 0;
-        this._list.connect('size-allocate',
-                           this._updateContentHeight.bind(this));
-
         this._list.set_selection_mode(Gtk.SelectionMode.NONE);
         this._filter = '';
         this._list.set_filter_func(this._filterRows.bind(this));
@@ -655,30 +679,6 @@ class UserList extends Gtk.ScrolledWindow {
         this._list.invalidate_filter();
     }
 
-    _updateContentHeight() {
-        if (this._updateHeightId != 0)
-            return;
-
-        this._updateHeightId = GLib.idle_add(GLib.PRIORITY_DEFAULT_IDLE, () => {
-            let topRow = this._list.get_row_at_y(this.vadjustment.value);
-            let membersShown = Math.min(this.numRows, MAX_USERS_SHOWN);
-            // topRow is unset when all rows are hidden due to filtering,
-            // base height on the first membersShown rows in that case
-            let index = 0;
-            if (topRow)
-                index = Math.min(topRow.get_index(), this.numRows - membersShown);
-            let height = 0;
-
-            for (let i = 0; i < membersShown; i++)
-                height += this._list.get_row_at_index(index + i).get_allocated_height();
-
-            this.max_content_height = height;
-            this.propagate_natural_height = true;
-            this._updateHeightId = 0;
-            return GLib.SOURCE_REMOVE;
-        });
-    }
-
     _onMemberRenamed(room, oldMember, newMember) {
         this._removeMember(oldMember);
         this._addMember(newMember);
